@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 #
-# Copyright 2011 Itaapy
+# Copyright 2010-2013 The pygit2 contributors
 #
 # This file is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2,
@@ -35,9 +35,6 @@ from pygit2 import GIT_SORT_TIME, GIT_SORT_REVERSE
 from . import utils
 
 
-__author__ = 'jdavid@itaapy.com (J. David Ibáñez)'
-
-
 # In the order given by git log
 log = [
     '2be5719152d4f82c7302b1c0932d8e5f0a4a0e98',
@@ -46,6 +43,27 @@ log = [
     '6aaa262e655dd54252e5813c8e5acd7780ed097d',
     'acecd5ea2924a4b900e7e149496e1f4b57976e51']
 
+REVLOGS = [
+    ('Nico von Geyso', 'checkout: moving from i18n to master'),
+    ('Nico von Geyso', 'commit: added bye.txt and new'),
+    ('Nico von Geyso', 'checkout: moving from master to i18n'),
+    ('J. David Ibañez', 'merge i18n: Merge made by recursive.'),
+    ('J. David Ibañez', 'commit: Add .gitignore file'),
+    ('J. David Ibañez', 'checkout: moving from i18n to master'),
+    ('J. David Ibañez', 'commit: Say hello in French'),
+    ('J. David Ibañez', 'commit: Say hello in Spanish'),
+    ('J. David Ibañez', 'checkout: moving from master to i18n'),
+    ('J. David Ibañez', 'commit (initial): First commit')
+]
+
+
+class RevlogTestTest(utils.RepoTestCase):
+    def test_log(self):
+        ref = self.repo.lookup_reference('HEAD')
+        for i, entry in enumerate(ref.log()):
+            self.assertEqual(entry.committer.name, REVLOGS[i][0])
+            self.assertEqual(entry.message, REVLOGS[i][1])
+
 
 class WalkerTest(utils.RepoTestCase):
 
